@@ -29,8 +29,8 @@ use Exporter 5.57 'import';     # exported import method
 #=====================================================================
 # Package Global Variables:
 
-our $VERSION = '1.000';
-# This file is part of HTML-Embellish 1.000 (February 1, 2014)
+our $VERSION = '1.001';
+# This file is part of HTML-Embellish 1.001 (April 11, 2015)
 
 our @EXPORT = qw(embellish);
 
@@ -132,7 +132,39 @@ sub processTextRefs
     s/(?<=\xA0)"(?=[ \t\n\r]|[\s\xA0]+$)/$rdquo/g;
     s/(?<=[,;.!?])"(?=[-$mdash])/$rdquo/go;
 
-    s/'(?=(?:cause|cept|d|e[mr]?e?|fraidy?|gainst|im|m|n|nam|nothers?|nuff|re?|rithmetic|s|scuse|spects?|t|til|tisn?|tw(?:asn?|ere?n?|ould\w*)|ud|uns?)\b|\d\d\W?s|\d\d(?!\w))/$rsquo/ig;
+    s/'(?=
+        (?: angmans?
+          | aves?
+          | cause
+          | cept
+          | d
+          | e[mr]?e?
+          | fraidy?
+          | gainst
+          | igh\w*
+          | im
+          | m
+          | n
+          | nam
+          | nothers?
+          | nuff
+          | onou?rs?
+          | re?
+          | rithmetic
+          | s
+          | scuse
+          | spects?
+          | t
+          | til
+          | tisn?
+          | tw(?:asn?|ere?n?|ould\w*)
+          | ud
+          | uns?
+        ) \b
+        | \d\d\W?s
+        | \d\d(?!\w)
+       )
+     /$rsquo/igx;
 
     s/'([ \xA0]?$rdquo)/$rsquo$1/go;
 
@@ -278,8 +310,8 @@ HTML::Embellish - Typographically enhance HTML trees
 
 =head1 VERSION
 
-This document describes version 1.000 of
-HTML::Embellish, released February 1, 2014.
+This document describes version 1.001 of
+HTML::Embellish, released April 11, 2015.
 
 =head1 SYNOPSIS
 
@@ -430,7 +462,7 @@ L<< https://github.com/madsen/html-embellish >>.
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Christopher J. Madsen.
+This software is copyright (c) 2015 by Christopher J. Madsen.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
